@@ -1,6 +1,6 @@
 package Statocles::App::Blog;
 # ABSTRACT: A blog application
-$Statocles::App::Blog::VERSION = '0.067';
+$Statocles::App::Blog::VERSION = '0.068';
 use Statocles::Base 'Class';
 use Getopt::Long qw( GetOptionsFromArray );
 use Statocles::Store;
@@ -68,12 +68,15 @@ sub command {
     }
     elsif ( $argv[0] eq 'post' ) {
         my %opt;
+        my @doc_opts = qw(author layout status tags template);
         GetOptionsFromArray( \@argv, \%opt,
             'date:s',
+            map { "$_:s" } @doc_opts,
         );
 
         my %doc = (
             %$default_post,
+            (map { defined $opt{$_} ? ( $_, $opt{$_} ) : () } @doc_opts),
             title => join " ", @argv[1..$#argv],
         );
 
@@ -226,7 +229,7 @@ sub index {
 
     # Add the feeds to all the pages
     for my $page ( @pages ) {
-        $page->_links->{feed} = \@feed_links;
+        $page->links( feed => @feed_links );
     }
 
     return ( @pages, @feed_pages );
@@ -284,7 +287,7 @@ sub tag_pages {
 
         # Add the feeds to all the pages
         for my $page ( @tag_pages ) {
-            $page->_links->{feed} = \@feed_links;
+            $page->links( feed => @feed_links );
         }
 
         push @pages, @tag_pages, @feed_pages;
@@ -419,7 +422,7 @@ Statocles::App::Blog - A blog application
 
 =head1 VERSION
 
-version 0.067
+version 0.068
 
 =head1 DESCRIPTION
 
