@@ -1,6 +1,6 @@
 package Statocles::Image;
 # ABSTRACT: A reference to an image
-$Statocles::Image::VERSION = '0.067';
+$Statocles::Image::VERSION = '0.068';
 
 use Statocles::Base 'Class';
 use Scalar::Util qw( blessed );
@@ -48,6 +48,13 @@ has role => (
     },
 );
 
+
+has data => (
+    is => 'ro',
+    isa => HashRef,
+    default => sub { {} },
+);
+
 1;
 
 __END__
@@ -60,7 +67,7 @@ Statocles::Image - A reference to an image
 
 =head1 VERSION
 
-version 0.067
+version 0.068
 
 =head1 SYNOPSIS
 
@@ -101,6 +108,11 @@ The height of the image, in pixels.
 The L<ARIA|http://www.w3.org/TR/wai-aria/> role for this image. If the L</alt>
 attribute is empty, this attribute defaults to C<"presentation">.
 
+=head2 data
+
+A hash of arbitrary data available to theme templates. This is a good place to
+put extra structured data like image credits, copyright, or location.
+
 =head1 AUTHOR
 
 Doug Bell <preaction@cpan.org>
