@@ -1,6 +1,6 @@
 package Statocles::Page;
 # ABSTRACT: Base class for rendering objects
-$Statocles::Page::VERSION = '0.067';
+$Statocles::Page::VERSION = '0.068';
 use Statocles::Base 'Role';
 use Statocles::Template;
 use Statocles::Util qw( uniq_by );
@@ -190,9 +190,9 @@ sub render {
 
 
 sub links {
-    my ( $self, $name, $add_link ) = @_;
-    if ( $add_link ) {
-        push @{ $self->_links->{ $name } }, Link->coerce( $add_link );
+    my ( $self, $name, @add_links ) = @_;
+    if ( @add_links ) {
+        push @{ $self->_links->{ $name } }, map { Link->coerce( $_ ) } @add_links;
         return;
     }
     my @links = uniq_by { $_->href }
@@ -234,7 +234,7 @@ Statocles::Page - Base class for rendering objects
 
 =head1 VERSION
 
-version 0.067
+version 0.068
 
 =head1 DESCRIPTION
 
@@ -379,8 +379,8 @@ If only one argument is given, returns a list of L<link
 objects|Statocles::Link>. In scalar context, returns the first link in
 the list.
 
-If two arguments are given, append the new link to the given key.
-C<$add_link> may be a URL string, a hash reference of L<link
+If two or more arguments are given, append the new links to the given
+key. C<$add_link> may be a URL string, a hash reference of L<link
 attributes|Statocles::Link/ATTRIBUTES>, or a L<Statocles::Link
 object|Statocles::Link>. When adding links, nothing is returned.
 
